summaryrefslogtreecommitdiff
path: root/unified_inventory
diff options
context:
space:
mode:
Diffstat (limited to 'unified_inventory')
-rw-r--r--unified_inventory/api.lua13
-rw-r--r--unified_inventory/depends.txt1
2 files changed, 11 insertions, 3 deletions
diff --git a/unified_inventory/depends.txt b/unified_inventory/depends.txt
index 8b13789..45b4a33 100644
--- a/unified_inventory/depends.txt
+++ b/unified_inventory/depends.txt
@@ -1 +1,2 @@
+creative
diff --git a/unified_inventory/api.lua b/unified_inventory/api.lua
index 5ff16fa..e386a76 100644
--- a/unified_inventory/api.lua
+++ b/unified_inventory/api.lua
@@ -230,7 +230,10 @@ unified_inventory.get_formspec = function(player,page)
end
if craft.type == "alloy" then
method="Alloy cooking"
- end
+ end
+ if craft.type == "extracting" then
+ method="Extracting"
+ end
formspec = formspec.."label[6,3;"..method.."]"
end
@@ -557,8 +560,12 @@ unified_inventory.update_recipe = function(player, stack_name, alternate)
local craft = crafts[alternate]
inv:set_stack("output", 1, craft.output)
local items=craft.items
- -- cook, fuel, grinding recipes
- if craft.type == "cooking" or craft.type == "fuel" or craft.type == "grinding" then
+
+ -- cooking, fuel, grinding, and extracting recipes
+ if craft.type == "cooking" or
+ craft.type == "fuel" or
+ craft.type == "grinding" or
+ craft.type == "extracting" then
def=unified_inventory.find_item_def(craft["items"][1])
if def then
inv:set_stack("build", 1, def)